from functools import wraps
from flask import request

def google_cloud_function(f):
    @wraps(f)
    def decorator(*args, **kwargs):
        req = request
        req.args = args
        req.kwargs = kwargs
        return f(req)
    
    return decorator


import time
from functools import wraps
from flask import request, current_app


class LambdaContext():

    function_name = ""
    function_version = ""
    invoked_function_arn = ""
    memory_limit_in_mb = float("inf")
    aws_request_id = ""
    log_group_name = ""
    log_stream_name = ""

    request_start_time = 0
    time_remaining = 0

    def get_remaining_time_in_millis(self):
        return (current_app.config['PERMANENT_SESSION_LIFETIME'] - (time.time() - self.request_start_time) * 1000)

    def __init__(self, function_name):
        self.request_start_time = time.time()
        self.function_name = function_name


def aws_lambda(f):
    @wraps(f)
    def decorator(*args, **kwargs):
        event = {
            "resource": "/",
            "path": request.path,
            "httpMethod": request.method,
            "requestContext": {
                "resourcePath": request.url_root,
                "httpMethod": request.method,
                "path": request.path,

            },
            "headers": request.headers,
            "multiValueHeaders": request.headers,
            "queryStringParameters": request.values,
            "multiValueQueryStringParameters": request.values,
            "pathParameters": request.view_args,
            "stageVariables": None,
            "body": request.get_data(),
            "isBase64Encoded": False,
        }
        context = LambdaContext(function_name=current_app.name)
        return f(event, context)

    return decorator



import setuptools

# Reads the content of your README.md into a variable to be used in the setup below
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name='flask-faas',
    packages=["flask_faas"],
    version='0.0.1',
    license='MIT',
    description='flask serverless decorator',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Shivanjan Chakravorty',
    author_email='schakravorty846@gmail.com',
    url='https://github.com/Glitchfix/flask-faas',
    project_urls={                                # Optional
        "Bug Tracker": "https://github.com/Glitchfix/flask-faas/issues"
    },
    install_requires=['flask', 'pytest'],
    keywords=["flask", "serverless", "faas", "flask-serverless", "lambda",
              "cloud function", "flask serverless"],  # descriptive meta-data
    classifiers=[                                   # https://pypi.org/classifiers
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Topic :: Internet :: WWW/HTTP :: WSGI',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],

    download_url="https://github.com/Glitchfix/flask-faas/archive/refs/tags/0.1.tar.gz",
)
